@@ -4,7 +4,9 @@
  * GChemPaint library
  * about.cc 
  *
- * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2005
+ *
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -26,12 +28,13 @@
 #include "about.h"
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <cstring>
+#include <string.h>
 
 void on_about (GtkWidget* widget, void* data)
 {
-	char * authors[] = {const_cast<char*> ("Jean Bréfort"), NULL};
-	char * artists[] = {const_cast<char*> ("Nestor Diaz"), NULL};
+	char * authors[] = {"Jean Bréfort", NULL};
+	char * artists[] = {"Nestor Diaz", NULL};
+//	char * documentors[] = {NULL};
 	char license[] = "This program is free software; you can redistribute it and/or\n" 
 		"modify it under the terms of the GNU General Public License as\n"
  		"published by the Free Software Foundation; either version 2 of the\n"
@@ -46,7 +49,7 @@ void on_about (GtkWidget* widget, void* data)
 		"USA";
 /* Note to translators: replace the following string with the appropriate credits for you lang */
 	char *translator_credits = _("translator_credits");
-	GdkPixbuf* pixbuf = gdk_pixbuf_new_from_file ( PIXMAPSDIR"/gchempaint_logo.png", NULL);
+	GdkPixbuf* pixbuf = gdk_pixbuf_new_from_file ( DATADIR"/"PACKAGE"/pixmaps/gchempaint_logo.png", NULL);
 	gtk_show_about_dialog (NULL,
 					"name", "GChemPaint",
 					"authors", authors,
