@@ -4,7 +4,9 @@
  * GChemPaint library
  * arrow.cc 
  *
- * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2004
+ *
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -72,7 +74,7 @@ bool gcpArrow::Load (xmlNodePtr node)
 		SetId (tmp);
 		xmlFree (tmp);
 	}
-	child = GetNodeByName (node, const_cast<char*> ("start"));
+	child = GetNodeByName (node, "start");
 	if (!child) return false;
 	tmp = (char*) xmlGetProp (child, (xmlChar*) "x");
 	if (!tmp) return false;
@@ -88,7 +90,7 @@ bool gcpArrow::Load (xmlNodePtr node)
 	xmlFree (tmp);
 	if (result)
 		return false;
-	child = GetNodeByName (node, const_cast<char*> ("end"));
+	child = GetNodeByName (node, "end");
 	if (!child) return false;
 	tmp = (char*) xmlGetProp (child, (xmlChar*) "x");
 	if (!tmp) return false;
@@ -111,13 +113,23 @@ void gcpArrow::SetSelected(GtkWidget* w, int state)
 {
 	gcpWidgetData* pData = (gcpWidgetData*)g_object_get_data(G_OBJECT(w), "data");
 	GnomeCanvasGroup* group = pData->Items[this];
-	gchar* color = NULL;
-	switch (state)
-	{	
-		case SelStateUnselected: color = Color; break;
-		case SelStateSelected: color = SelectColor; break;
-		case SelStateUpdating: color = AddColor; break;
-		case SelStateErasing: color = DeleteColor; break;
+	gchar* color;
+	switch (state) {	
+	case SelStateUnselected:
+		color = Color;
+		break;
+	case SelStateSelected:
+		color = SelectColor;
+		break;
+	case SelStateUpdating:
+		color = AddColor;
+		break;
+	case SelStateErasing:
+		color = DeleteColor;
+		break;
+	default:
+		color = Color;
+		break;
 	}
 	GList* il = group->item_list;
 	while (il)
