@@ -4,7 +4,9 @@
  * GChemPaint library
  * mesomery.cc 
  *
- * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2005
+ *
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -33,12 +35,12 @@
 #include "mesomery-arrow.h"
 #include "mesomer.h"
 #include <glib/gi18n.h>
-#include <cmath>
+#include <math.h>
 #include <set>
 
 gcpMesomery::gcpMesomery (): Object (MesomeryType)
 {
-	SetId (const_cast<char*> ("msy1"));
+	SetId ("msy1");
 }
 
 gcpMesomery::~gcpMesomery ()
@@ -50,7 +52,7 @@ gcpMesomery::~gcpMesomery ()
 	gcpMesomeryArrow *arrow;
 	gcpDocument *pDoc = reinterpret_cast<gcpDocument *> (GetDocument ());
 	gcpOperation *pOp = pDoc->GetCurrentOperation ();
-	while ((pObj = GetFirstChild (i))) {
+	while (pObj = GetFirstChild (i)) {
 		if (pObj->GetType () == MesomeryArrowType) {
 			arrow = reinterpret_cast<gcpMesomeryArrow*> (pObj);
 			arrow->SetStartMesomer (NULL);
@@ -764,7 +766,7 @@ bool gcpMesomery::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
 
 gcpMesomery::gcpMesomery (Object* parent, gcpMesomer *mesomer): Object (MesomeryType)
 {
-	SetId (const_cast<char*> ("msy1"));
+	SetId ("msy1");
 	SetParent (parent);
 	AddChild (mesomer);
 	set<Object *> Objects;
