@@ -4,7 +4,9 @@
  * GChemPaint library
  * molecule.cc 
  *
- * Copyright (C) 2001-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2005
+ *
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -22,29 +24,17 @@
  * USA
  */
 
-#ifndef HAS_OPENBABEL_2
-#	include <mol.h>
-#	undef PACKAGE
-#	undef PACKAGE_BUGREPORT
-#	undef PACKAGE_NAME
-#	undef PACKAGE_STRING
-#	undef PACKAGE_TARNAME
-#	undef PACKAGE_VERSION
-#	undef VERSION
-#endif
 #include "gchempaint-config.h"
 #include "molecule.h"
 #include "document.h"
 #include "view.h"
 #include "application.h"
 #include "tool.h"
+#include "stringdlg.h"
 #include <math.h>
 #include <unistd.h>
 #include <locale.h>
-#ifdef HAS_OPENBABEL_2
-#	include <openbabel/mol.h>
-#	include <openbabel/obconversion.h>
-#endif
+#include <openbabel/obconversion.h>
 
 static void do_export_to_ghemical (gcpMolecule* pMol)
 {
@@ -57,9 +47,25 @@ static void do_select_alignment (GObject *action, gcpMolecule* pMol)
 	pMol->SelectAlignmentItem (object);
 }
 
+static void do_build_inchi (gcpMolecule* pMol)
+{
+	pMol->ShowInChI ();
+}
+
+static void do_build_smiles (gcpMolecule* pMol)
+{
+	pMol->BuildSmiles ();
+}
+
+static void do_show_webbook (gcpMolecule* pMol)
+{
+	pMol->ShowWebbook ();
+}
+
 gcpMolecule::gcpMolecule(TypeId Type): Object(Type)
 {
 	m_Alignment = NULL;
+	m_Changed = true;
 }
 
 gcpMolecule::gcpMolecule(gcpAtom* pAtom): Object(MoleculeType)
@@ -67,6 +73,7 @@ gcpMolecule::gcpMolecule(gcpAtom* pAtom): Object(MoleculeType)
 	AddAtom(pAtom);
 	gcpChain* pChain = new gcpChain(this, pAtom); //will find the cycles
 	delete pChain;
+	m_Changed = true;
 }
 
 gcpMolecule::~gcpMolecule()
@@ -171,7 +178,7 @@ bool gcpMolecule::Merge(gcpMolecule* pMolecule, bool RemoveDuplicates)
 				ma->pAtom = pAtom;
 				endj = AtomMap.end ();
 				for (j = AtomMap.begin (); j != endj; j++) {
-					if ((b1 = (gcpBond*) pAtom->GetBond ((*j).second->pAtom))) {
+					if (b1 = (gcpBond*) pAtom->GetBond ((*j).second->pAtom)) {
 						b0 = (gcpBond*) (*i)->GetBond ((*j).first);
 						if (b0) {
 							ma->sb++;
@@ -392,6 +399,7 @@ bool gcpMolecule::Load (xmlNodePtr node)
 		if (!m_Alignment)
 			return false;
 	}
+	m_Changed = true;
 	return true;
 }
 
@@ -449,7 +457,7 @@ Object* gcpMolecule::GetAtomAt(double x, double y, double z)
 	std::list<gcpBond*>::iterator n, end = m_Bonds.end();
 	Object* pObj = NULL;
 	for (n = m_Bonds.begin(); n != end; n++)
-		if ((pObj = (*n)->GetAtomAt (x, y)))
+		if (pObj = (*n)->GetAtomAt (x, y))
 			break;
 	return pObj;
 }
@@ -483,11 +491,29 @@ bool gcpMolecule::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
 	bool result = false;
 	GtkActionGroup *group = gtk_action_group_new ("molecule");
 	GtkAction *action;
-	if (!m_Fragments.size () && ((gcpDocument*) GetDocument ())->GetApplication ()->HaveGhemical ()) {
-		action = gtk_action_new ("ghemical", _("Export molecule to Ghemical"), NULL, NULL);
-		g_signal_connect_swapped (action, "activate", G_CALLBACK (do_export_to_ghemical), this);
+	action = gtk_action_new ("Molecule", _("Molecule"), NULL, NULL);
+	gtk_action_group_add_action (group, action);
+	if (!m_Fragments.size ()) {
+		if (((gcpDocument*) GetDocument ())->GetApplication ()->HaveGhemical ()) {
+			action = gtk_action_new ("ghemical", _("Export molecule to Ghemical"), NULL, NULL);
+			g_signal_connect_swapped (action, "activate", G_CALLBACK (do_export_to_ghemical), this);
+			gtk_action_group_add_action (group, action);
+			gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menu action='Molecule'><menuitem action='ghemical'/></menu></popup></ui>", -1, NULL);
+		}
+		if (((gcpDocument*) GetDocument ())->GetApplication ()->HaveInChI ()) {
+			action = gtk_action_new ("inchi", _("Generate InChI"), NULL, NULL);
+			g_signal_connect_swapped (action, "activate", G_CALLBACK (do_build_inchi), this);
+			gtk_action_group_add_action (group, action);
+			gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menu action='Molecule'><menuitem action='inchi'/></menu></popup></ui>", -1, NULL);
+			action = gtk_action_new ("webbook", _("NIST WebBook page for this molecule"), NULL, NULL);
+			g_signal_connect_swapped (action, "activate", G_CALLBACK (do_show_webbook), this);
+			gtk_action_group_add_action (group, action);
+			gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menu action='Molecule'><menuitem action='webbook'/></menu></popup></ui>", -1, NULL);
+		}
+		action = gtk_action_new ("smiles", _("Generate Smiles"), NULL, NULL);
+		g_signal_connect_swapped (action, "activate", G_CALLBACK (do_build_smiles), this);
 		gtk_action_group_add_action (group, action);
-		gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menuitem action='ghemical'/></popup></ui>", -1, NULL);
+		gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menu action='Molecule'><menuitem action='smiles'/></menu></popup></ui>", -1, NULL);
 		result = true;
 	}
 	if (m_Bonds.size ()) {
@@ -495,7 +521,7 @@ bool gcpMolecule::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
 		g_signal_connect (action, "activate", G_CALLBACK (do_select_alignment), this);
 		g_object_set_data (G_OBJECT (action), "item", object);
 		gtk_action_group_add_action (group, action);
-		gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menuitem action='select-align'/></popup></ui>", -1, NULL);
+		gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menu action='Molecule'><menuitem action='select-align'/></menu></popup></ui>", -1, NULL);
 		result = true;
 	}
 	if (result)
@@ -507,16 +533,50 @@ bool gcpMolecule::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
 
 void gcpMolecule::ExportToGhemical ()
 {
-	double xav = 0., yav = 0., zf;
-	unsigned n = m_Atoms.size();
-#ifdef HAS_OPENBABEL_2
 	OBMol Mol;
 	OBConversion Conv;
 	OBFormat* pOutFormat = Conv.FindFormat ("gpr");
 	Conv.SetInAndOutFormats (pOutFormat, pOutFormat);
-#else
-	OBMol Mol(UNDEFINED, GHEMICAL);
-#endif
+	BuildOBMol (Mol);
+	char *tmpname = g_strdup ("/tmp/gcp2gprXXXXXX");
+	int f = g_mkstemp (tmpname);
+	gchar *old_num_locale;
+	close (f);
+	ofstream ofs;
+	ofs.open(tmpname);
+	if (!ofs) throw (int) 1;
+	old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
+	setlocale(LC_NUMERIC, "C");
+	Conv.Write (&Mol, &ofs);
+	setlocale(LC_NUMERIC, old_num_locale);
+	g_free(old_num_locale);
+	ofs.close();
+	char *command_line = g_strconcat ("ghemical -f ", tmpname, NULL);	
+	g_free (tmpname);
+	g_spawn_command_line_async (command_line, NULL);
+	g_free (command_line);
+}
+
+void gcpMolecule::SelectAlignmentItem (Object *child)
+{
+	m_Alignment = (m_Alignment != child)? child: NULL;
+	EmitSignal (OnChangedSignal);
+}
+
+xmlNodePtr gcpMolecule::Save (xmlDocPtr xml)
+{
+	xmlNodePtr node = Object::Save (xml);
+	if (!node)
+		return NULL;
+	if (m_Alignment)
+		xmlNewProp (node, (const xmlChar*) "valign", (const xmlChar*) m_Alignment->GetId ());
+	return node;
+}
+
+void gcpMolecule::BuildOBMol (OBMol &Mol)
+{
+	double xav = 0., yav = 0., zf;
+	unsigned n = m_Atoms.size();
 	map<string, unsigned> AtomTable;
 	list<gcpAtom*>::iterator ia, enda = m_Atoms.end ();
 	list<gcpBond*> BondList;
@@ -531,7 +591,6 @@ void gcpMolecule::ExportToGhemical ()
 	gcpAtom* pgAtom;
 	OBAtom obAtom;
 	unsigned index = 1;
-	gchar *old_num_locale;
 	map<Atom*, Bond*>::iterator i;
 	gcpBond *pBond;
 	Mol.BeginModify();
@@ -572,41 +631,94 @@ void gcpMolecule::ExportToGhemical ()
 		Mol.AddBond(start, end, order, 0);
 	}
 	Mol.EndModify();
-	char *tmpname = g_strdup ("/tmp/gcp2gprXXXXXX");
-	int f = g_mkstemp (tmpname);
-	close (f);
-	ofstream ofs;
-	ofs.open(tmpname);
-	if (!ofs) throw (int) 1;
-	old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
-	setlocale(LC_NUMERIC, "C");
-#ifdef HAS_OPENBABEL_2
+}
+
+void gcpMolecule::BuildInChI ()
+{
+	OBMol Mol;
+	OBConversion Conv;
+	BuildOBMol (Mol);
+	OBFormat *pInChIFormat = Conv.FindFormat ("inchi"), *pMolFormat = Conv.FindFormat ("mol");
+	if (pInChIFormat) {
+		Conv.SetInAndOutFormats (pMolFormat, pInChIFormat);
+		Conv.SetOptions ("xt", OpenBabel::OBConversion::OUTOPTIONS);
+		ostringstream ofs;
+		char *old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
+		setlocale (LC_NUMERIC, "C");
+		Conv.Write (&Mol, &ofs);
+		setlocale (LC_NUMERIC, old_num_locale);
+		g_free (old_num_locale);
+		// remove "INCHI=" and the new line char at the end
+		m_InChI = ofs.str ().substr (6, ofs.str ().length () - 8);
+	} else {
+		Conv.SetInAndOutFormats (pMolFormat, pMolFormat);
+		char *tmpname = g_strdup ("/tmp/inchiXXXXXX");
+		int f = g_mkstemp (tmpname);
+		close (f);
+		ofstream ofs;
+		ofs.open (tmpname);
+		char *old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
+		setlocale (LC_NUMERIC, "C");
+		Conv.Write (&Mol, &ofs);
+		setlocale (LC_NUMERIC, old_num_locale);
+		ofs.close ();
+		// calling main_inchi -STDIO -AuxNone -NoLabels
+		char *command = g_strdup_printf ("main_inchi %s -STDIO -AuxNone -NoLabels", tmpname);
+		char *output, *errors;
+		g_spawn_command_line_sync (command, &output, &errors, NULL, NULL);
+		if (output) {
+			// remove the new line char at the end
+			output[strlen (output) - 1] = 0;
+			m_InChI = output + 6;
+			g_free (output);
+		}
+		if (errors)
+			g_free (errors);
+		g_free (command);
+		g_free (old_num_locale);
+		remove (tmpname);
+		g_free (tmpname);
+	}
+	m_Changed = false;
+}
+
+void gcpMolecule::BuildSmiles ()
+{
+	OBMol Mol;
+	OBConversion Conv;
+	OBFormat* pOutFormat = Conv.FindFormat ("smi");
+	Conv.SetInAndOutFormats (pOutFormat, pOutFormat);
+	BuildOBMol (Mol);
+	ostringstream ofs;
+	char *old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
+	setlocale (LC_NUMERIC, "C");
 	Conv.Write (&Mol, &ofs);
-#else
-	OBFileFormat fileFormat;
-	fileFormat.WriteMolecule(ofs, Mol, "3D");
-#endif
-	setlocale(LC_NUMERIC, old_num_locale);
-	g_free(old_num_locale);
-	ofs.close();
-	char *command_line = g_strconcat ("ghemical -f ", tmpname, NULL);	
-	g_free (tmpname);
-	g_spawn_command_line_async (command_line, NULL);
-	g_free (command_line);
+	setlocale (LC_NUMERIC, old_num_locale);
+	//TODO: do something with the string
+	g_free (old_num_locale);
+	string str = ofs.str ().substr (0, ofs.str ().length () - 2);
+	new gcpStringDlg (reinterpret_cast<gcpDocument *>(GetDocument ()), str, gcpStringDlg::SMILES);
 }
 
-void gcpMolecule::SelectAlignmentItem (Object *child)
+void gcpMolecule::ShowInChI ()
 {
-	m_Alignment = (m_Alignment != child)? child: NULL;
-	EmitSignal (OnChangedSignal);
+	if (m_Changed)
+		BuildInChI ();
+	new gcpStringDlg (reinterpret_cast<gcpDocument *>(GetDocument ()), m_InChI, gcpStringDlg::INCHI);
 }
 
-xmlNodePtr gcpMolecule::Save (xmlDocPtr xml)
+void gcpMolecule::ShowWebbook ()
 {
-	xmlNodePtr node = Object::Save (xml);
-	if (!node)
-		return NULL;
-	if (m_Alignment)
-		xmlNewProp (node, (const xmlChar*) "valign", (const xmlChar*) m_Alignment->GetId ());
-	return node;
+	if (m_Changed)
+		BuildInChI ();
+	if (m_InChI.length () == 0)
+		return; //should emit at least a warning
+	string uri = string ("http://webbook.nist.gov/cgi/cbook.cgi?Name=") + m_InChI.c_str () + string ("&Units=SI");
+	((gcpDocument*) GetDocument ())->GetApplication ()->ShowURI (uri);
+}
+
+bool gcpMolecule::OnSignal (SignalId Signal, Object *Child)
+{
+	m_Changed = true;
+	return true;
 }
