@@ -4,7 +4,9 @@
  * GChemPaint library
  * text.cc 
  *
- * Copyright (C) 2002-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2005
+ *
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -140,7 +142,7 @@ static gint gnome_canvas_rich_text_gcp_event(GnomeCanvasItem *item, GdkEvent *ev
 	gcpText* pText = (gcpText*)g_object_get_data(G_OBJECT(item), "object");
 	if (pText)
 		if (!pText->OnEvent(event))
-			return (* GNOME_CANVAS_ITEM_CLASS(parent_class)->event)(item, event);
+			(* GNOME_CANVAS_ITEM_CLASS(parent_class)->event)(item, event);
 	return true;
 }
 
@@ -213,7 +215,7 @@ bool gcpText::SaveNode(xmlDocPtr xml, xmlNodePtr node, GtkTextIter *iter, GtkTex
 			*iter = *end;
 		}
 		char *rn, *text = gtk_text_buffer_get_text(m_buf, &start, iter, true);
-		while ((rn = strchr(text, '\n')))
+		while (rn = strchr(text, '\n'))
 		{
 			xmlNodeAddContentLen(node, (xmlChar*)text, rn - text);
 			text = rn + 1;
@@ -249,13 +251,13 @@ bool gcpText::SaveNode(xmlDocPtr xml, xmlNodePtr node, GtkTextIter *iter, GtkTex
 		g_value_init(&val, G_TYPE_STRING);
 		g_object_get_property((GObject*) tag, "name", &val);
 		const gchar* name = g_value_get_string(&val);
-		if (!strcmp(name, "bold")) tagname = const_cast<char*> ("b");
-		else if  (!strcmp(name, "italic")) tagname = const_cast<char*> ("i");
-		else if  (!strcmp(name, "underline")) tagname = const_cast<char*> ("u");
-		else if  (!strcmp(name, "strikethrough")) tagname = const_cast<char*> ("s");
-		else if  (!strcmp(name, "subscript")) tagname = const_cast<char*> ("sub");
-		else if  (!strcmp(name, "superscript")) tagname = const_cast<char*> ("sup");
-		else tagname = const_cast<char*> ("font");
+		if (!strcmp(name, "bold")) tagname = "b";
+		else if  (!strcmp(name, "italic")) tagname = "i";
+		else if  (!strcmp(name, "underline")) tagname = "u";
+		else if  (!strcmp(name, "strikethrough")) tagname = "s";
+		else if  (!strcmp(name, "subscript")) tagname = "sub";
+		else if  (!strcmp(name, "superscript")) tagname = "sup";
+		else tagname = "font";
 		OtherTagList = g_slist_append(OtherTagList, tag);
 		TagList = g_slist_remove(TagList, tag);
 		xmlNodePtr child = xmlNewDocNode(xml, NULL, (xmlChar*)tagname, NULL);
@@ -656,21 +658,21 @@ void gcpText::SetSelected(GtkWidget* w, int state)
 	GnomeCanvasGroup* group = pData->Items[this];
 	gchar* color;
 	switch (state) {	
-		case SelStateUnselected:
-			color = const_cast<char*> ("white");
-			break;
-		case SelStateSelected:
-			color = SelectColor;
-			break;
-		case SelStateUpdating:
-			color = AddColor;
-			break;
-		case SelStateErasing:
-			color = DeleteColor;
-			break;
-		default:
-			color = const_cast<char*> ("white");
-			break;
+	case SelStateUnselected:
+		color = "white";
+		break;
+	case SelStateSelected:
+		color = SelectColor;
+		break;
+	case SelStateUpdating:
+		color = AddColor;
+		break;
+	case SelStateErasing:
+		color = DeleteColor;
+		break;
+	default:
+		color = "white";
+		break;
 	}
 	g_object_set(G_OBJECT(g_object_get_data(G_OBJECT(group), "rect")), "fill_color", color, NULL);
 }
