@@ -4,7 +4,9 @@
  * GChemPaint library
  * widgetdata.h
  *
- * Copyright (C) 2002-2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2004
+ *
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -72,6 +74,7 @@ public:
 	double ArrowDist;
 	double ObjectPadding;
 	double SignPadding;
+	double Zoom;
 	std::map<Object*, GnomeCanvasGroup*>Items;
 	std::list<Object*>SelectedObjects;
 	
