@@ -4,7 +4,9 @@
  * GChemPaint arrows plugin
  * arrowtool.cc 
  *
- * Copyright (C) 2001-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2005
+ *
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -46,7 +48,7 @@ static char* ToolNames[] = {
 };
 
 
-class gcpArrowToolDlg: public gcpDialog
+class gcpArrowToolDlg: public Dialog
 {
 public:
 	gcpArrowToolDlg (gcpApplication* App, bool FullHeads);
@@ -64,7 +66,7 @@ static void on_default (gcpArrowToolDlg* dlg)
 	dlg->OnDefault ();
 }
 
-gcpArrowToolDlg::gcpArrowToolDlg (gcpApplication* App, bool FullHeads): gcpDialog(App, GLADEDIR"/arrowtool.glade", "arrowtool")
+gcpArrowToolDlg::gcpArrowToolDlg (gcpApplication* App, bool FullHeads): Dialog(App, DATADIR"/gchempaint-unstable/ui/arrowtool.glade", "arrowtool")
 {
 	GtkTable *table = GTK_TABLE (glade_xml_get_widget (xml, "heads_table"));
 	GnomeCanvas *canvas = GNOME_CANVAS (gnome_canvas_new_aa ());
@@ -145,18 +147,19 @@ gcpArrowToolDlg::gcpArrowToolDlg (gcpApplication* App, bool FullHeads): gcpDialo
 	if (FullHeads) gtk_toggle_button_set_active (full_btn, true);
 	GtkWidget* w = glade_xml_get_widget (xml, "default");
 	g_signal_connect_swapped (w, "clicked", G_CALLBACK (on_default), this);
-	App->SetDialog ("ArrowHeads", this);
+	reinterpret_cast<gcpApplication*> (App)->SetDialog ("ArrowHeads", this);
 	gtk_widget_show_all (GTK_WIDGET (dialog));
 }
 
 gcpArrowToolDlg::~gcpArrowToolDlg ()
 {
-	m_App->SetDialog ("ArrowHeads", NULL);
+	reinterpret_cast<gcpApplication*> (m_App)->SetDialog ("ArrowHeads", NULL);
 }
 
 bool gcpArrowToolDlg::Apply ()
 {
-	gcpArrowTool *tool = (gcpArrowTool*) m_App->GetTool ("ReversibleArrow");
+	gcpArrowTool *tool = (gcpArrowTool*)
+			reinterpret_cast<gcpApplication*> (m_App)->GetTool ("ReversibleArrow");
 	if (tool)
 		tool->SetArrowType (gtk_toggle_button_get_active (full_btn)? gcpFullReversibleArrow: gcpReversibleArrow);
 	return true;
