@@ -4,7 +4,9 @@
  * GChemPaint bonds plugin
  * bondtool.cc
  *
- * Copyright (C) 2001-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2005
+ *
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -286,6 +288,7 @@ void gcpBondTool::OnRelease()
 		m_pOp->AddObject (m_pObjectGroup, 1);
 		pDoc->FinishOperation ();
 		m_pOp = NULL;
+		m_pObject->EmitSignal (OnChangedSignal);
 		return;
 	} else {
 		if (m_pOp)
@@ -620,6 +623,62 @@ void gcpDownBondTool::SetType(gcpBond* pBond)
 	pBond->SetType(DownBondType);
 }
 
+gcpForeBondTool::gcpForeBondTool(gcpApplication *App): gcpBondTool(App, "ForeBond", 4)
+{
+}
+
+gcpForeBondTool::~gcpForeBondTool()
+{
+}
+
+void gcpForeBondTool::Draw()
+{
+	double dx, dy, x1, y1, x2, y2;
+	x1 = sqrt(square(m_x1 - m_x0) + square(m_y1 - m_y0));
+	if (x1 == 0) return;
+	dx = (m_y0 - m_y1) / x1 * m_pData->StereoBondWidth / 2;
+	dy = (m_x1 - m_x0) / x1 * m_pData->StereoBondWidth / 2;
+	points->coords[0] = m_x0 + dx;
+	points->coords[1] = m_y0 + dy;
+	points->coords[2] = m_x1 + dx;
+	points->coords[3] = m_y1 + dy;
+	points->coords[4] = m_x1 - dx;
+	points->coords[5] = m_y1 - dy;
+	points->coords[6] = m_x0 - dx;
+	points->coords[7] = m_y0 - dy;
+	m_pItem = gnome_canvas_item_new(
+								m_pGroup,
+								gnome_canvas_polygon_get_type(),
+								"points", points,
+								"fill_color", AddColor,
+								NULL);
+	gnome_canvas_item_get_bounds(GNOME_CANVAS_ITEM(m_pItem), &x1, &y1, &x2, &y2);
+	gnome_canvas_request_redraw(GNOME_CANVAS(m_pWidget), (int)x1, (int)y1, (int)x2, (int)y2);
+}
+
+void gcpForeBondTool::UpdateBond ()
+{
+	Draw();
+}
+
+void gcpForeBondTool::FinalizeBond ()
+{
+	if (m_bChanged)
+	{
+		gcpBond* pBond = (gcpBond*) m_pObject;
+		if (pBond->GetType () != ForeBondType) {
+			pBond->SetType (ForeBondType);
+			m_pView->Remove (m_pObject);
+			m_pView->AddObject (m_pObject);
+		}
+	}
+}
+
+void gcpForeBondTool::SetType (gcpBond* pBond)
+{
+	pBond->SetType (ForeBondType);
+}
+
 gcpSquiggleBondTool::gcpSquiggleBondTool(gcpApplication *App): gcpBondTool(App, "SquiggleBond", 4)
 {
 }
