@@ -4,7 +4,9 @@
  * GChemPaint cycles plugin
  * plugin.cc 
  *
- * Copyright (C) 2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004
+ *
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -39,7 +41,7 @@ gcpCyclesPlugin::~gcpCyclesPlugin()
 
 void gcpCyclesPlugin::Populate (gcpApplication* App)
 {
-	App->AddUI (GLADEDIR"/cycles.xml");
+	App->AddUI (DATADIR"/gchempaint-unstable/ui/cycles.xml");
 	new gcpCycleTool (App, 3);
 	new gcpCycleTool (App, 4);
 	new gcpCycleTool (App, 5);
