@@ -2,7 +2,9 @@
  * GChemPaint selection plugin
  * groupdlg.h
  *
- * Copyright (C) 2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2005
+ *
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -25,10 +27,12 @@
 
 #include "lib/document.h"
 #include "lib/widgetdata.h"
-#include "lib/dialog.h"
 #include "group.h"
+#include <gcu/dialog.h>
 
-class gcpGroupDlg: public gcpDialog
+using namespace gcu;
+
+class gcpGroupDlg: public Dialog
 {
 public:
 	gcpGroupDlg (gcpDocument *Doc, gcpGroup *group);
