@@ -4,7 +4,9 @@
  * GChemPaint text plugin
  * plugin.cc 
  *
- * Copyright (C) 2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004
+ *
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -42,7 +44,7 @@ gcpTextPlugin::~gcpTextPlugin()
 
 void gcpTextPlugin::Populate (gcpApplication* App)
 {
-	App->AddUI (GLADEDIR"/text.xml");
+	App->AddUI (DATADIR"/gchempaint-unstable/ui/text.xml");
 	new gcpTextTool (App);
 	new gcpFragmentTool (App);
 }
