@@ -4,7 +4,9 @@
  * GChemPaint
  * gchempaint-bonobo.cc 
  *
- * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2003
+ *
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -27,8 +29,8 @@
 #include "lib/view.h"
 #include "lib/widgetdata.h"
 #include "bonoboapp.h"
+#include <stdlib.h>
 #include <unistd.h>
-#include <cstdlib>
 
 extern int CurElt;
 
@@ -94,9 +96,9 @@ static void on_save(gpointer p, Bonobo_Stream stream, const Bonobo_Persist_Conte
 	xmlDocPtr xml = ps->pDoc->BuildXMLTree();
 	if (xml)
 	{
-		unsigned char* tmp;
+		char* tmp;
 		int size;
-		xmlDocDumpMemory (xml, (xmlChar**) (&tmp), &size);
+		xmlDocDumpMemory(xml, (xmlChar**)(&tmp), &size);
 		if (tmp)
 		{
 			bonobo_stream_client_write (stream, tmp, size, ev);
@@ -166,14 +168,14 @@ static void set_prop (BonoboPropertyBag *bag,  const BonoboArg *arg, guint arg_i
 	switch (arg_id)
 	{
 		case PROP_BGCOLOR:
-			g_object_set(G_OBJECT(pData->Background), "fill_color", BONOBO_ARG_GET_STRING(arg), NULL);
+			g_object_set(G_OBJECT(pData->Background), "fill_color", BONOBO_ARG_GET_STRING(arg));
 			break;
 /*		case PROP_EDITABLE:
 			{
 				gcpDocument* pDoc = (gcpDocument*) g_object_get_data(G_OBJECT(widget), "doc");
 				if (pDoc) pDoc->SetEditable(BONOBO_ARG_GET_BOOLEAN(arg));
-			}
-			break;*/
+			}*/
+			break;
 		default:
 			bonobo_exception_set(ev, ex_Bonobo_PropertyBag_NotFound);
 			break;
@@ -253,6 +255,8 @@ on_save_as_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname)
 	App->OnSaveAs ();
 }
 
+extern void on_print(GtkWidget* widget, void* data);
+
 static void
 on_properties_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname)
 {
@@ -500,7 +504,7 @@ BonoboObject * gchempaint_factory(BonoboGenericFactory * fact, const char *compo
 	gcpBonoboApp* App = new gcpBonoboApp();
 	gcpDocument* pDoc =  new gcpDocument(App, false);
 	if (!pDoc) return NULL;
-	if (!strcmp (component_id, "OAFIID:gchempaint_control"))
+	if (!strcmp (component_id, "OAFIID:gchempaint_unstable_control"))
 	{
 		retval = (BonoboObject*) gcp_bonobo_control_new(pDoc);
 		if (!retval)  delete pDoc;
@@ -517,12 +521,12 @@ BonoboObject * gchempaint_factory(BonoboGenericFactory * fact, const char *compo
 
 int main (int argc, char *argv[])
 {
-	bindtextdomain(PACKAGE, LOCALEDIR);
+	bindtextdomain(PACKAGE, DATADIR"/locale");
 #ifdef ENABLE_NLS
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
 	textdomain(PACKAGE);
 	gtk_init (&argc, &argv);
-	BONOBO_FACTORY_INIT ("gchempaint", VERSION, &argc, argv);		
-	return bonobo_generic_factory_main ("OAFIID:gchempaint_factory", gchempaint_factory, NULL);
+	BONOBO_FACTORY_INIT ("gchempaint_unstable", VERSION, &argc, argv);		
+	return bonobo_generic_factory_main ("OAFIID:gchempaint_unstable_factory", gchempaint_factory, NULL);
 }
